@@ -8,6 +8,7 @@ from smarkets.itertools import (
     is_sorted,
     listitems,
     listkeys,
+    listmap,
     listvalues,
     mapkeys,
     mapvalues,
@@ -39,7 +40,7 @@ def check_group(i, n, o):
 
 
 def test_listxxx():
-    data = dict(a='a', b='x', c=123)
+    data = dict(a='a', b='x', c='123')
     keys = listkeys(data)
     values = listvalues(data)
     items = listitems(data)
@@ -47,8 +48,8 @@ def test_listxxx():
     eq_(set(types), set([list]))
 
     eq_(sorted(keys), ['a', 'b', 'c'])
-    eq_(sorted(values), [123, 'a', 'x'])
-    eq_(sorted(items), [('a', 'a'), ('b', 'x'), ('c', 123)])
+    eq_(sorted(values), ['123', 'a', 'x'])
+    eq_(sorted(items), [('a', 'a'), ('b', 'x'), ('c', '123')])
 
 
 def test_inverse_mapping_works():
@@ -102,3 +103,8 @@ def test_copy_keys_if_present():
         ['a', 'b', 'c']
     )
     eq_(destination, {'a': 'new val a', 'b': 'val b'})
+
+
+def test_listmap_works_and_returns_a_list():
+    result = listmap(str, [1, 2])
+    eq_((result, type(result)), (['1', '2'], list))
